Compare all list elements, producing a logical matrix with the result of each
pairwise comparison. Row and column names are taken from names(ls).
Compare all list elements, producing a logical matrix with the result of each
pairwise comparison. Row and column names are taken from names(ls).