This is a wrapper for rmarkdown::draft(). By default, it copies the
relevant files for the "nb1" RMD template into the scripts/ folder (created
by setup_project()).
Details
The R Notebook template "nb1" has three related files.
_output.ymlcontains the YAML options underhtml_notebook. These will be shared by any markdown documents in the same directory (see Shared Options, R Markdown: The Definitive Guide).render.Rcontains a call tormarkdown::render()that's prepopulated to execute the notebook and save the.nb.htmlreport in the project'soutput/directory (created bysetup_project()).skeleton.Rmdis the R Notebook file. Whenuse_rmd_template()is executed, the file will be saved with the name specified in thefilenameargument.